@@ -1,5 +1,5 @@
 package Perl::Critic::Policy::TryTiny::RequireUse;
-$Perl::Critic::Policy::TryTiny::RequireUse::VERSION = '0.02';
+$Perl::Critic::Policy::TryTiny::RequireUse::VERSION = '0.03';
 use strict;
 use warnings;
 
@@ -26,7 +26,7 @@ sub violates {
 
     my $try_package = _find_package( $try );
 
-    my $includes = $doc->find(sub{
+    my $included = $doc->find_any(sub{
         $_[1]->isa('PPI::Statement::Include')
             and
         defined( $_[1]->module() )
@@ -46,9 +46,9 @@ sub violates {
         $_[1]->type() eq 'use'
             and
         _find_package( $_[1] ) eq $try_package
-    }) || [];
+    });
 
-    return if @$includes;
+    return if $included;
 
     return $self->violation( $DESC, $EXPL, $try );
 }
@@ -65,8 +65,8 @@ sub _find_package {
             return $element->namespace() if $element->ancestor_of( $original );
 
             # If we've hit a non-block package then thats our package.
-            my $blocks = $element->find('PPI::Structure::Block') || [];
-            return $element->namespace() if !@$blocks;
+            my $blocks = $element->find_any('PPI::Structure::Block');
+            return $element->namespace() if !$blocks;
         }
 
         # Keep walking backwards until we match the above logic or we get to
@@ -119,6 +119,16 @@ alternative to this policy.
 
 Aran Clary Deltac <bluefeetE<64>gmail.com>
 
+=head1 CONTRIBUTORS
+
+=over
+
+=item *
+
+Graham TerMarsch <grahamE<64>howlingfrog.com>
+
+=back
+
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to L<ZipRecruiter|https://www.ziprecruiter.com/>
